@@ -196,7 +196,7 @@ pub fn include_glade(args: TokenStream) -> TokenStream {
 /* Remove the UI extension of a file, and return its bare name */
 fn remove_ui_extension(file_name: &str) -> Option<Cow<'_, str>> {
 	lazy_static! {
-		static ref UI_FILE_REGEX: Regex = Regex::new(r"^(.*)\.glade|\.ui").unwrap();
+		static ref UI_FILE_REGEX: Regex = Regex::new(r"^(.*)(\.glade|\.ui)$").unwrap();
 	}
 	UI_FILE_REGEX.is_match(file_name).then(|| UI_FILE_REGEX.replace(file_name, "$1"))
 }
@@ -206,4 +206,5 @@ fn test_remove_ui_extension() {
 	assert_eq!("foo", remove_ui_extension("foo.ui").unwrap());
 	assert_eq!("bar", remove_ui_extension("bar.glade").unwrap());
 	assert_eq!(None, remove_ui_extension("foo.rs"));
+	assert_eq!(None, remove_ui_extension("foo.glade~"));
 }
